@@ -5,6 +5,9 @@
 #
 # SPDX-License-Identifier: MIT
 
+# add timestamps
+export PS4='[$(date "+%T.%3N")]'" $PS4"
+
 set -euo pipefail
 set -x
 
